@@ -163,7 +163,7 @@ public:
 	SocketService	* svc,
 	ts_list_head	* head
     ) :
-	SocketPort( svc, server ),
+	SocketPort( NULL, server ),
 	ts_list_item( head )
     {
 	cerr << "ChatterSession Created\n";
@@ -179,6 +179,7 @@ public:
 
 	// Set yerself to time out in 10 seconds
 	setTimer( 100000 );
+	attach(svc);
     }
 
     //
