@@ -51,6 +51,10 @@
 #include <cc++/socket.h>
 #endif
 
+#ifndef	CCXX_MIME_H_
+#include <cc++/mime.h>
+#endif
+
 #ifdef	CCXX_NAMESPACES
 namespace ost {
 #endif
@@ -108,6 +112,7 @@ public:
 		methodHttpGet,
 		methodHttpPut,
 		methodHttpPost,
+		methodHttpPostMultipart,
 		methodFtpGet,
 		methodFtpPut,
 		methodFileGet,
@@ -227,6 +232,16 @@ public:
 	 */
 	Error post(const char *url, const char **vars, size_t buffer = 512);
 
+	/**
+	 * Post URL with MIME multipart form.
+	 *
+	 * @return url error code.
+	 * @param url name of resource.
+	 * @param reference to multipart form.
+	 * @param size of buffer.
+	 */
+	Error post(const char *url, MIMEMultipartForm &form, size_t buffer = 512);
+
 	/**
 	 * Used to fetch header information for a resource.
 	 *
