@@ -258,7 +258,7 @@ void ThreadQueue::run(void)
 	{
 		Semaphore::wait();
 		if(!started)
-			sleep(~0);
+			sleep((timeout_t)~0);
 		startQueue();
 		while(first)
 		{
