@@ -440,7 +440,11 @@ int AtomicCounter::operator++(void)
 #ifdef	HAVE_ATOMIC_AIX
 	return fetch_and_add((atomic_p)&counter, 1);
 #elif   defined(HAVE_GCC_BITS_ATOMIC) || defined(HAVE_GCC_CXX_BITS_ATOMIC)
-	return __exchange_and_add(&counter, 1);
+	// Modified by JCE from 2v1.3.8 source, 30/Mar/2005
+	// BUG FIX: __exchange_and_add() does not seem to return updated <counter>
+	__exchange_and_add(&counter, 1);
+	return counter;
+	// end modification by JCE
 #else
 	atomic_inc(&atomic);
 	return atomic_read(&atomic);
@@ -452,7 +456,11 @@ int AtomicCounter::operator--(void)
 #ifdef	HAVE_ATOMIC_AIX
 	return fetch_and_add((atomic_p)&counter, -1);
 #elif   defined(HAVE_GCC_BITS_ATOMIC) || defined(HAVE_GCC_CXX_BITS_ATOMIC)
-	return __exchange_and_add(&counter, -1);
+	// Modified by JCE from 2v1.3.8 source, 30/Mar/2005
+	// BUG FIX: __exchange_and_add() does not seem to return updated <counter>
+	__exchange_and_add(&counter, -1);
+	return counter;
+	// end modification by JCE
 #else
 	int chk = atomic_dec_and_test(&atomic);
 	if(chk)
@@ -469,7 +477,11 @@ int AtomicCounter::operator+=(int change)
 #ifdef	HAVE_ATOMIC_AIX
 	return fetch_and_add((atomic_p)&counter, change);
 #elif   defined(HAVE_GCC_BITS_ATOMIC) || defined(HAVE_GCC_CXX_BITS_ATOMIC)
-	return __exchange_and_add(&counter, change);
+	// Modified by JCE from 2v1.3.8 source, 30/Mar/2005
+	// BUG FIX: __exchange_and_add() does not seem to return updated <counter>
+	__exchange_and_add(&counter, change);
+	return counter;
+	// end modification by JCE
 #else
 	atomic_add(change, &atomic);
 	return atomic_read(&atomic);
@@ -481,7 +493,11 @@ int AtomicCounter::operator-=(int change)
 #ifdef	HAVE_ATOMIC_AIX
 	return fetch_and_add((atomic_p)&counter, -change);
 #elif   defined(HAVE_GCC_BITS_ATOMIC) || defined(HAVE_GCC_CXX_BITS_ATOMIC)
-	return __exchange_and_add(&counter, -change);
+	// Modified by JCE from 2v1.3.8 source, 30/Mar/2005
+	// BUG FIX: __exchange_and_add() does not seem to return updated <counter>
+	__exchange_and_add(&counter, -change);
+	return counter;
+	// end modification by JCE
 #else
 	atomic_sub(change, &atomic);
 	return atomic_read(&atomic);
