@@ -125,7 +125,7 @@ typedef	unsigned (__stdcall *exec_t)(void *);
 #define CCXX_SUSPEND_MODE_ONE_SIGNAL 3
 #define	CCXX_SUSPEND_MODE_MACH 4
 
-#if defined(_THR_MACH) && !defined(_DARWIN6_)
+#if defined(_THR_MACH) && !defined(MACOSX)
 #define	CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_MACH
 #elif defined(HAVE_PTHREAD_SUSPEND)
 #define CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_NOT_RECURSIVE
