@@ -75,6 +75,27 @@
 /**
 * @todo Why may be need using kernel object Mutex as a background for ost::Mutex?
 */
+
+/**
+ * Determine if platform SDK is installed.  Comment this line out
+ * if using VS6 without any Platform SDK updates...
+ */
+#define	HAVE_PLATFORMSDK
+
+/**
+ * Some sanity checks for platformsdk support based on build env.
+ */
+
+#ifndef	HAVE_PLATFORMSDK
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#define	HAVE_PLATFORMSDK
+#else
+#if defined(__MINGW32__) || defined(__CYGWIN32__)
+#undef	HAVE_PLATFORMSDK
+#endif
+#endif
+#endif
+
 // Select the way, that the ost::Mutex based on.
 //#define MUTEX_UNDERGROUND_WIN32_MUTEX
 #define MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
@@ -82,12 +103,12 @@
 // Require for compiling with critical sections.  
 #define _WIN32_WINNT 0x0400
 
-#if	defined(_MSC_VER) && _MSC_VER < 1300	
+#if	!defined(HAVE_PLATFORMSDK)
 #include <windows.h>
 #endif
 #include <winsock2.h>
 #include <ws2tcpip.h>
-#if !defined(_MSC_VER) || _MSC_VER >= 1300
+#if defined(HAVE_PLATFORMSDK)
 #include <windows.h>
 #define CCXX_IPV6
 #endif
